api.world.v1.test_helpers.timezone package — Argus-Toolbelt 1.0 documentation

# api.world.v1.test_helpers.timezone package

## Submodules

## api.world.v1.test_helpers.timezone.get_time_zones module

`api.world.v1.test_helpers.timezone.get_time_zones.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/world/v1/timezone, respond with HTTP 403

`api.world.v1.test_helpers.timezone.get_time_zones.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/world/v1/timezone, respond with HTTP 404

`api.world.v1.test_helpers.timezone.get_time_zones.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/world/v1/timezone, respond with HTTP 200

`api.world.v1.test_helpers.timezone.get_time_zones.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/world/v1/timezone, respond with HTTP 401

## Module contents